package com.ruoyi.interfaces.service;

import java.util.List;
import com.ruoyi.interfaces.domain.MdDataSetSql;

/**
 * sql数据集Service接口
 * 
 * @author 朱得糠
 * @date 2025-09-02
 */
public interface IMdDataSetSqlService 
{
    /**
     * 查询sql数据集
     * 
     * @param id sql数据集主键
     * @return sql数据集
     */
    public MdDataSetSql selectMdDataSetSqlByDcCode(String id);

    /**
     * 查询sql数据集列表
     * 
     * @param mdDataSetSql sql数据集
     * @return sql数据集集合
     */
    public List<MdDataSetSql> selectMdDataSetSqlList(MdDataSetSql mdDataSetSql);

    /**
     * 新增sql数据集
     * 
     * @param mdDataSetSql sql数据集
     * @return 结果
     */
    public int insertMdDataSetSql(MdDataSetSql mdDataSetSql);

    /**
     * 修改sql数据集
     * 
     * @param mdDataSetSql sql数据集
     * @return 结果
     */
    public int updateMdDataSetSql(MdDataSetSql mdDataSetSql);

    /**
     * 批量删除sql数据集
     * 
     * @param ids 需要删除的sql数据集主键集合
     * @return 结果
     */
    public int deleteMdDataSetSqlByIds(Long[] ids);

    /**
     * 删除sql数据集信息
     * 
     * @param id sql数据集主键
     * @return 结果
     */
    public int deleteMdDataSetSqlById(Long id);

    int deleteMdDataSetSqlByDcCode(String dcCode);

}
